@@ -37,6 +37,7 @@ except:
 from specmate_globals import appName
 from specmate_frontend import MainWindow
 from specmate_backend import specmate_backend
+import gettext
 #----------------------------------------------------------------------------
 #----------------------------------------------------------------------------
 
@@ -51,6 +52,7 @@ def specmateMain(argv):
 	@type argv: list of strings
 	"""
 	backend=specmate_backend(argv)
+	gettext.install("app")
 	app = wx.App()
 	mainFrame = MainWindow(None,-1,appName,backend)
 	mainFrame.Show()
