@@ -474,7 +474,15 @@ class MainWindow_windowContents(MainWindow_helperFunctions):
 		"""
 		Put the wxmpl-PlotPanel and Navigation-Tollbar in Main-Window
 		"""
-		self.plotPanel	=	wxmpl.PlotPanel(self,-1,size=(10.0,6.17))
+                displayPX=wx.DisplaySize()
+                displayMM=wx.DisplaySizeMM()
+		displayInchX=displayMM[0]/25.4
+		displayInchY=displayMM[1]/25.4
+                ppiX=int(displayPX[0]/displayInchX)
+                ppiY=int(displayPX[1]/displayInchY)
+                ppi=min(ppiX,ppiY)
+
+                self.plotPanel	=	wxmpl.PlotPanel(self,-1,size=(displayInchX*0.75,displayInchX*0.75*0.617),dpi=ppi)
 		wxmpl.EVT_POINT(self.plotPanel, -1, self._handleMouseClicks)
 	        self.sizer = wx.BoxSizer(wx.VERTICAL)
 	        self.sizer.Add(self.plotPanel, 1, wx.EXPAND, 5)
