@@ -30,7 +30,7 @@ except:
 	print "Please install wxPython!"
 	sys.exit(1)
 
-from specmate_globals import *
+#from specmate_globals import *
 from specmate_globals import appName,version,developers,description,copyright,license_long
 #----------------------------------------------------------------------------
 #----------------------------------------------------------------------------
@@ -370,11 +370,11 @@ class specmate_menubar(wx.Frame):
 		refMenu	=	wx.Menu()
 		##menuItems for refsMenu
 		item_addReference	=	refMenu.Append(wx.ID_ANY, 'Add reference spectrum ...', 'Add a new reference spectrum.')
-		item_editRefNames	=	refMenu.Append(wx.ID_ANY, 'Edit reference names ...', 'Edit names of reference spectra.')
+		#item_editRefNames	=	refMenu.Append(wx.ID_ANY, 'Edit reference names ...', 'Edit names of reference spectra.')
 		item_manageReference	=	refMenu.Append(wx.ID_ANY, 'Manage references ...', 'Manage reference spectra already added.')
 		##Binds for refsMenu
 		self.Bind(wx.EVT_MENU, self._onMenuAddRef, item_addReference)
-		self.Bind(wx.EVT_MENU, self._onMenuEditRefNames, item_editRefNames)
+		#self.Bind(wx.EVT_MENU, self._onMenuEditRefNames, item_editRefNames)
 		self.Bind(wx.EVT_MENU, self._onMenuManageRef, item_manageReference)
 		return(refMenu)
 	#--------------------------------------------------------------------------------
@@ -538,7 +538,7 @@ class specmate_menubar(wx.Frame):
 		menubar.Append(self._createPeakMenu(), '&Peaks')
 		menubar.Append(self._createRefMenu(), '&References')
 		menubar.Append(self._createBackgroundMenu(), '&Baseline')
-		menubar.Append(self._createFunctionMenu(), 'F&unctions')
+		#menubar.Append(self._createFunctionMenu(), 'F&unctions')
 		menubar.Append(self._createFitMenu(), 'F&it')
 		#menubar.Append(self._createGraphMenu(), '&Graph')
 		menubar.Append(self._createHelpMenu(), '&Help')
